Response<D> class

Implementers

Constructors

Response({String message = 'ok', D? data, String? body, dynamic error, int statusCode = 0, Map<String, List<String>>? headers, dynamic extra})

Properties

body → String?
final
data ↔ D?
getter/setter pair
error ↔ dynamic
getter/setter pair
extra ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, List<String>>?
final
message → String
final
ok → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

copyWith<T>(Response response, {required String message, T? data, dynamic error, dynamic extra, String? body, required int statusCode, Map<String, List<String>>? headers}) → Response<T>