ResponseCancel<T> class

Inheritance

Constructors

ResponseCancel({String message = 'failure', dynamic error, dynamic extra, String? body, int statusCode = 0, Map<String, List<String>>? headers})

Properties

body → String?
finalinherited
data ↔ T?
getter/setter pairinherited
error ↔ dynamic
getter/setter pairinherited
extra ↔ dynamic
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, List<String>>?
finalinherited
message → String
finalinherited
ok → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited